"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(
    hub,
    ctx,
    delivery_stream_name: str,
    delivery_stream_encryption_configuration_input: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Enables server-side encryption (SSE) for the delivery stream.  This operation is asynchronous. It returns immediately. When you invoke it, Kinesis Data Firehose first sets the encryption status of the stream to ENABLING, and then to ENABLED. The encryption status of a delivery stream is the Status property in DeliveryStreamEncryptionConfiguration. If the operation fails, the encryption status changes to ENABLING_FAILED. You can continue to read and write data to your delivery stream while the encryption status is ENABLING, but the data is not encrypted. It can take up to 5 seconds after the encryption status changes to ENABLED before all records written to the delivery stream are encrypted. To find out whether a record or a batch of records was encrypted, check the response elements PutRecordOutput$Encrypted and PutRecordBatchOutput$Encrypted, respectively. To check the encryption status of a delivery stream, use DescribeDeliveryStream. Even if encryption is currently enabled for a delivery stream, you can still invoke this operation on it to change the ARN of the CMK or both its type and ARN. If you invoke this method to change the CMK, and the old CMK is of type CUSTOMER_MANAGED_CMK, Kinesis Data Firehose schedules the grant it had on the old CMK for retirement. If the new CMK is of type CUSTOMER_MANAGED_CMK, Kinesis Data Firehose creates a grant that enables it to use the new CMK to encrypt and decrypt data and to manage the grant. If a delivery stream already has encryption enabled and then you invoke this operation to change the ARN of the CMK or both its type and ARN and you get ENABLING_FAILED, this only means that the attempt to change the CMK failed. In this case, encryption remains enabled with the old CMK. If the encryption status of your delivery stream is ENABLING_FAILED, you can invoke this operation again with a valid CMK. The CMK must be enabled and the key policy mustn't explicitly deny the permission for Kinesis Data Firehose to invoke KMS encrypt and decrypt operations. You can enable SSE for a delivery stream only if it's a delivery stream that uses DirectPut as its source.  The StartDeliveryStreamEncryption and StopDeliveryStreamEncryption operations have a combined limit of 25 calls per delivery stream per 24 hours. For example, you reach the limit if you call StartDeliveryStreamEncryption 13 times and StopDeliveryStreamEncryption 12 times for the same delivery stream in a 24-hour period.

    Args:
        delivery_stream_name(str): The name of the delivery stream for which you want to enable server-side encryption (SSE).
        delivery_stream_encryption_configuration_input(Dict, optional): Used to specify the type and Amazon Resource Name (ARN) of the KMS key needed for Server-Side Encryption (SSE). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.firehose.delivery_stream.encryption.start(
                ctx, delivery_stream_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.firehose.delivery_stream.encryption.start delivery_stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="firehose",
        operation="start_delivery_stream_encryption",
        op_kwargs={
            "DeliveryStreamName": delivery_stream_name,
            "DeliveryStreamEncryptionConfigurationInput": delivery_stream_encryption_configuration_input,
        },
    )


async def stop(hub, ctx, delivery_stream_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables server-side encryption (SSE) for the delivery stream.  This operation is asynchronous. It returns immediately. When you invoke it, Kinesis Data Firehose first sets the encryption status of the stream to DISABLING, and then to DISABLED. You can continue to read and write data to your stream while its status is DISABLING. It can take up to 5 seconds after the encryption status changes to DISABLED before all records written to the delivery stream are no longer subject to encryption. To find out whether a record or a batch of records was encrypted, check the response elements PutRecordOutput$Encrypted and PutRecordBatchOutput$Encrypted, respectively. To check the encryption state of a delivery stream, use DescribeDeliveryStream.  If SSE is enabled using a customer managed CMK and then you invoke StopDeliveryStreamEncryption, Kinesis Data Firehose schedules the related KMS grant for retirement and then retires it after it ensures that it is finished delivering records to the destination. The StartDeliveryStreamEncryption and StopDeliveryStreamEncryption operations have a combined limit of 25 calls per delivery stream per 24 hours. For example, you reach the limit if you call StartDeliveryStreamEncryption 13 times and StopDeliveryStreamEncryption 12 times for the same delivery stream in a 24-hour period.

    Args:
        delivery_stream_name(str): The name of the delivery stream for which you want to disable server-side encryption (SSE).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.firehose.delivery_stream.encryption.stop(
                ctx, delivery_stream_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.firehose.delivery_stream.encryption.stop delivery_stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="firehose",
        operation="stop_delivery_stream_encryption",
        op_kwargs={"DeliveryStreamName": delivery_stream_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def execute(
    hub,
    ctx,
    provisioned_product_id: str,
    service_action_id: str,
    execute_token: str,
    accept_language: str = None,
    parameters: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Executes a self-service action against a provisioned product.

    Args:
        provisioned_product_id(str): The identifier of the provisioned product.
        service_action_id(str): The self-service action identifier. For example, act-fs7abcd89wxyz.
        execute_token(str): An idempotency token that uniquely identifies the execute request.
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        parameters(Dict, optional): A map of all self-service action parameters and their values. If a provided parameter is of a special type, such as TARGET, the provided value will override the default value generated by AWS Service Catalog. If the parameters field is not provided, no additional parameters are passed and default values will be used for any special parameters such as TARGET. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioned_product.service_action.execute(
                ctx, provisioned_product_id=value, service_action_id=value, execute_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioned_product.service_action.execute provisioned_product_id=value, service_action_id=value, execute_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="execute_provisioned_product_service_action",
        op_kwargs={
            "ProvisionedProductId": provisioned_product_id,
            "ServiceActionId": service_action_id,
            "ExecuteToken": execute_token,
            "AcceptLanguage": accept_language,
            "Parameters": parameters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    channel_name: str,
    duration_minutes: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about your channel's schedule.

    Args:
        channel_name(str): The identifier for the channel you are working on.
        duration_minutes(str, optional): The schedule duration in minutes. The maximum duration is 4320 minutes (three days). Defaults to None.
        max_results(int, optional): Upper bound on number of records to return. The maximum number of results is 100. Defaults to None.
        next_token(str, optional): Pagination token from the GET list request. Use the token to fetch the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.channel.schedule.get(ctx, channel_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.channel.schedule.get channel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="get_channel_schedule",
        op_kwargs={
            "ChannelName": channel_name,
            "DurationMinutes": duration_minutes,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    service_name: str,
    container_name: str,
    start_time: str = None,
    end_time: str = None,
    filter_pattern: str = None,
    page_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the log events of a container of your Amazon Lightsail container service. If your container service has more than one node (i.e., a scale greater than 1), then the log events that are returned for the specified container are merged from all nodes on your container service.  Container logs are retained for a certain amount of time. For more information, see Amazon Lightsail endpoints and quotas in the AWS General Reference.

    Args:
        service_name(str): The name of the container service for which to get a container log.
        container_name(str): The name of the container that is either running or previously ran on the container service for which to return a log.
        start_time(str, optional): The start of the time interval for which to get log data. Constraints:   Specified in Coordinated Universal Time (UTC).   Specified in the Unix time format. For example, if you wish to use a start time of October 1, 2018, at 8 PM UTC, specify 1538424000 as the start time.   You can convert a human-friendly time to Unix time format using a converter like Epoch converter. Defaults to None.
        end_time(str, optional): The end of the time interval for which to get log data. Constraints:   Specified in Coordinated Universal Time (UTC).   Specified in the Unix time format. For example, if you wish to use an end time of October 1, 2018, at 9 PM UTC, specify 1538427600 as the end time.   You can convert a human-friendly time to Unix time format using a converter like Epoch converter. Defaults to None.
        filter_pattern(str, optional): The pattern to use to filter the returned log events to a specific term. The following are a few examples of filter patterns that you can specify:   To return all log events, specify a filter pattern of "".   To exclude log events that contain the ERROR term, and return all other log events, specify a filter pattern of "-ERROR".   To return log events that contain the ERROR term, specify a filter pattern of "ERROR".   To return log events that contain both the ERROR and Exception terms, specify a filter pattern of "ERROR Exception".   To return log events that contain the ERROR or the Exception term, specify a filter pattern of "?ERROR ?Exception".  . Defaults to None.
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetContainerLog request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.container.log.get(
                ctx, service_name=value, container_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.container.log.get service_name=value, container_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_container_log",
        op_kwargs={
            "serviceName": service_name,
            "containerName": container_name,
            "startTime": start_time,
            "endTime": end_time,
            "filterPattern": filter_pattern,
            "pageToken": page_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, location_type: str = None) -> Dict:
    r"""
    **Autogenerated function**

    A temporary Amazon S3 location to copy your files from a source location to stage or use as a scratch space in Habanero notebook.

    Args:
        location_type(str, optional): Specify the type of the working location.    SAGEMAKER - Use the Amazon S3 location as a temporary location to store data content when working with FinSpace Notebooks that run on SageMaker studio.    INGESTION - Use the Amazon S3 location as a staging location to copy your data content and then use the location with the changeset creation operation.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.finspace_data.working_location.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.finspace_data.working_location.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="finspace-data",
        operation="get_working_location",
        op_kwargs={"locationType": location_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    scope: str,
    capacity: int,
    visibility_config: Dict,
    description: str = None,
    rules: List = None,
    tags: List = None,
    custom_response_bodies: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a RuleGroup per the specifications provided.   A rule group defines a collection of rules to inspect and control web requests that you can use in a WebACL. When you create a rule group, you define an immutable capacity limit. If you update a rule group, you must stay within the capacity. This allows others to reuse the rule group with confidence in its capacity requirements.

    Args:
        name(str): The name of the rule group. You cannot change the name of a rule group after you create it.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        capacity(int): The web ACL capacity units (WCUs) required for this rule group. When you create your own rule group, you define this, and you cannot change it after creation. When you add or modify the rules in a rule group, WAF enforces this limit. You can check the capacity for a set of rules using CheckCapacity. WAF uses WCUs to calculate and control the operating resources that are used to run your rules, rule groups, and web ACLs. WAF calculates capacity differently for each rule type, to reflect the relative cost of each rule. Simple rules that cost little to run use fewer WCUs than more complex rules that use more processing power. Rule group capacity is fixed at creation, which helps users plan their web ACL WCU usage when they use a rule group. The WCU limit for web ACLs is 1,500. .
        description(str, optional): A description of the rule group that helps with identification. . Defaults to None.
        rules(List, optional): The Rule statements used to identify the web requests that you want to allow, block, or count. Each rule includes one top-level statement that WAF uses to identify matching web requests, and parameters that govern how WAF handles them. . Defaults to None.
        visibility_config(Dict): Defines and enables Amazon CloudWatch metrics and web request sample collection. .
        tags(List, optional): An array of key:value pairs to associate with the resource. Defaults to None.
        custom_response_bodies(Dict, optional): A map of custom response keys and content bodies. When you create a rule with a block action, you can send a custom response to the web request. You define these for the rule group, and then use them in the rules that you define in the rule group.  For information about customizing web requests and responses, see Customizing web requests and responses in WAF in the WAF Developer Guide.  For information about the limits on count and size for custom request and response settings, see WAF quotas in the WAF Developer Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.rule_group.create(
                ctx, name=value, scope=value, capacity=value, visibility_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.rule_group.create name=value, scope=value, capacity=value, visibility_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="create_rule_group",
        op_kwargs={
            "Name": name,
            "Scope": scope,
            "Capacity": capacity,
            "Description": description,
            "Rules": rules,
            "VisibilityConfig": visibility_config,
            "Tags": tags,
            "CustomResponseBodies": custom_response_bodies,
        },
    )


async def delete(hub, ctx, name: str, scope: str, id_: str, lock_token: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified RuleGroup.

    Args:
        name(str): The name of the rule group. You cannot change the name of a rule group after you create it.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        id_(str): A unique identifier for the rule group. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
        lock_token(str): A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.rule_group.delete(
                ctx, name=value, scope=value, id_=value, lock_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.rule_group.delete name=value, scope=value, id_=value, lock_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="delete_rule_group",
        op_kwargs={"Name": name, "Scope": scope, "Id": id_, "LockToken": lock_token},
    )


async def get(
    hub, ctx, name: str = None, scope: str = None, id_: str = None, arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the specified RuleGroup.

    Args:
        name(str, optional): The name of the rule group. You cannot change the name of a rule group after you create it. Defaults to None.
        scope(str, optional): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   . Defaults to None.
        id_(str, optional): A unique identifier for the rule group. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete. Defaults to None.
        arn(str, optional): The Amazon Resource Name (ARN) of the entity. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.rule_group.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.rule_group.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="get_rule_group",
        op_kwargs={"Name": name, "Scope": scope, "Id": id_, "ARN": arn},
    )


async def list_all(
    hub, ctx, scope: str, next_marker: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an array of RuleGroupSummary objects for the rule groups that you manage.

    Args:
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        next_marker(str, optional): When you request a list of objects with a Limit setting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns a NextMarker value in the response. To retrieve the next batch of objects, provide the marker from the prior call in your next request. Defaults to None.
        limit(int, optional): The maximum number of objects that you want WAF to return for this request. If more objects are available, in the response, WAF provides a NextMarker value that you can use in a subsequent call to get the next batch of objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.rule_group.list_all(ctx, scope=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.rule_group.list_all scope=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="list_rule_groups",
        op_kwargs={"Scope": scope, "NextMarker": next_marker, "Limit": limit},
    )


async def update(
    hub,
    ctx,
    name: str,
    scope: str,
    id_: str,
    visibility_config: Dict,
    lock_token: str,
    description: str = None,
    rules: List = None,
    custom_response_bodies: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified RuleGroup.  This operation completely replaces the mutable specifications that you already have for the rule group with the ones that you provide to this call. To modify the rule group, retrieve it by calling GetRuleGroup, update the settings as needed, and then provide the complete rule group specification to this call.   A rule group defines a collection of rules to inspect and control web requests that you can use in a WebACL. When you create a rule group, you define an immutable capacity limit. If you update a rule group, you must stay within the capacity. This allows others to reuse the rule group with confidence in its capacity requirements.

    Args:
        name(str): The name of the rule group. You cannot change the name of a rule group after you create it.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        id_(str): A unique identifier for the rule group. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
        description(str, optional): A description of the rule group that helps with identification. . Defaults to None.
        rules(List, optional): The Rule statements used to identify the web requests that you want to allow, block, or count. Each rule includes one top-level statement that WAF uses to identify matching web requests, and parameters that govern how WAF handles them. . Defaults to None.
        visibility_config(Dict): Defines and enables Amazon CloudWatch metrics and web request sample collection. .
        lock_token(str): A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation. .
        custom_response_bodies(Dict, optional): A map of custom response keys and content bodies. When you create a rule with a block action, you can send a custom response to the web request. You define these for the rule group, and then use them in the rules that you define in the rule group.  For information about customizing web requests and responses, see Customizing web requests and responses in WAF in the WAF Developer Guide.  For information about the limits on count and size for custom request and response settings, see WAF quotas in the WAF Developer Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.rule_group.update(
                ctx, name=value, scope=value, id_=value, visibility_config=value, lock_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.rule_group.update name=value, scope=value, id_=value, visibility_config=value, lock_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="update_rule_group",
        op_kwargs={
            "Name": name,
            "Scope": scope,
            "Id": id_,
            "Description": description,
            "Rules": rules,
            "VisibilityConfig": visibility_config,
            "LockToken": lock_token,
            "CustomResponseBodies": custom_response_bodies,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(hub, ctx, shard_iterator: str, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets data records from a Kinesis data stream's shard. Specify a shard iterator using the ShardIterator parameter. The shard iterator specifies the position in the shard from which you want to start reading data records sequentially. If there are no records available in the portion of the shard that the iterator points to, GetRecords returns an empty list. It might take multiple calls to get to a portion of the shard that contains records. You can scale by provisioning multiple shards per stream while considering service limits (for more information, see Amazon Kinesis Data Streams Limits in the Amazon Kinesis Data Streams Developer Guide). Your application should have one thread per shard, each reading continuously from its stream. To read from a stream continually, call GetRecords in a loop. Use GetShardIterator to get the shard iterator to specify in the first GetRecords call. GetRecords returns a new shard iterator in NextShardIterator. Specify the shard iterator returned in NextShardIterator in subsequent calls to GetRecords. If the shard has been closed, the shard iterator can't return more data and GetRecords returns null in NextShardIterator. You can terminate the loop when the shard is closed, or when the shard iterator reaches the record with the sequence number or other attribute that marks it as the last record to process. Each data record can be up to 1 MiB in size, and each shard can read up to 2 MiB per second. You can ensure that your calls don't exceed the maximum supported size or throughput by using the Limit parameter to specify the maximum number of records that GetRecords can return. Consider your average record size when determining this limit. The maximum number of records that can be returned per call is 10,000. The size of the data returned by GetRecords varies depending on the utilization of the shard. The maximum size of data that GetRecords can return is 10 MiB. If a call returns this amount of data, subsequent calls made within the next 5 seconds throw ProvisionedThroughputExceededException. If there is insufficient provisioned throughput on the stream, subsequent calls made within the next 1 second throw ProvisionedThroughputExceededException. GetRecords doesn't return any data when it throws an exception. For this reason, we recommend that you wait 1 second between calls to GetRecords. However, it's possible that the application will get exceptions for longer than 1 second. To detect whether the application is falling behind in processing, you can use the MillisBehindLatest response attribute. You can also monitor the stream using CloudWatch metrics and other mechanisms (see Monitoring in the Amazon Kinesis Data Streams Developer Guide). Each Amazon Kinesis record includes a value, ApproximateArrivalTimestamp, that is set when a stream successfully receives and stores a record. This is commonly referred to as a server-side time stamp, whereas a client-side time stamp is set when a data producer creates or sends the record to a stream (a data producer is any data source putting data records into a stream, for example with PutRecords). The time stamp has millisecond precision. There are no guarantees about the time stamp accuracy, or that the time stamp is always increasing. For example, records in a shard or across a stream might have time stamps that are out of order. This operation has a limit of five transactions per second per shard.

    Args:
        shard_iterator(str): The position in the shard from which you want to start sequentially reading data records. A shard iterator specifies this position using the sequence number of a data record in the shard.
        limit(int, optional): The maximum number of records to return. Specify a value of up to 10,000. If you specify a value that is greater than 10,000, GetRecords throws InvalidArgumentException. The default value is 10,000. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.record.get_all(ctx, shard_iterator=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.record.get_all shard_iterator=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="get_records",
        op_kwargs={"ShardIterator": shard_iterator, "Limit": limit},
    )


async def put(
    hub,
    ctx,
    stream_name: str,
    data: bytes,
    partition_key: str,
    explicit_hash_key: str = None,
    sequence_number_for_ordering: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Writes a single data record into an Amazon Kinesis data stream. Call PutRecord to send data into the stream for real-time ingestion and subsequent processing, one record at a time. Each shard can support writes up to 1,000 records per second, up to a maximum data write total of 1 MiB per second. You must specify the name of the stream that captures, stores, and transports the data; a partition key; and the data blob itself. The data blob can be any type of data; for example, a segment from a log file, geographic/location data, website clickstream data, and so on. The partition key is used by Kinesis Data Streams to distribute data across shards. Kinesis Data Streams segregates the data records that belong to a stream into multiple shards, using the partition key associated with each data record to determine the shard to which a given data record belongs. Partition keys are Unicode strings, with a maximum length limit of 256 characters for each key. An MD5 hash function is used to map partition keys to 128-bit integer values and to map associated data records to shards using the hash key ranges of the shards. You can override hashing the partition key to determine the shard by explicitly specifying a hash value using the ExplicitHashKey parameter. For more information, see Adding Data to a Stream in the Amazon Kinesis Data Streams Developer Guide.  PutRecord returns the shard ID of where the data record was placed and the sequence number that was assigned to the data record. Sequence numbers increase over time and are specific to a shard within a stream, not across all shards within a stream. To guarantee strictly increasing ordering, write serially to a shard and use the SequenceNumberForOrdering parameter. For more information, see Adding Data to a Stream in the Amazon Kinesis Data Streams Developer Guide.  After you write a record to a stream, you cannot modify that record or its order within the stream.  If a PutRecord request cannot be processed because of insufficient provisioned throughput on the shard involved in the request, PutRecord throws ProvisionedThroughputExceededException.  By default, data records are accessible for 24 hours from the time that they are added to a stream. You can use IncreaseStreamRetentionPeriod or DecreaseStreamRetentionPeriod to modify this retention period.

    Args:
        stream_name(str): The name of the stream to put the data record into.
        data(bytes): The data blob to put into the record, which is base64-encoded when the blob is serialized. When the data blob (the payload before base64-encoding) is added to the partition key size, the total size must not exceed the maximum record size (1 MiB).
        partition_key(str): Determines which shard in the stream the data record is assigned to. Partition keys are Unicode strings with a maximum length limit of 256 characters for each key. Amazon Kinesis Data Streams uses the partition key as input to a hash function that maps the partition key and associated data to a specific shard. Specifically, an MD5 hash function is used to map partition keys to 128-bit integer values and to map associated data records to shards. As a result of this hashing mechanism, all data records with the same partition key map to the same shard within the stream.
        explicit_hash_key(str, optional): The hash value used to explicitly determine the shard the data record is assigned to by overriding the partition key hash. Defaults to None.
        sequence_number_for_ordering(str, optional): Guarantees strictly increasing sequence numbers, for puts from the same client and to the same partition key. Usage: set the SequenceNumberForOrdering of record n to the sequence number of record n-1 (as returned in the result when putting record n-1). If this parameter is not set, records are coarsely ordered based on arrival time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.record.put(
                ctx, stream_name=value, data=value, partition_key=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.record.put stream_name=value, data=value, partition_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="put_record",
        op_kwargs={
            "StreamName": stream_name,
            "Data": data,
            "PartitionKey": partition_key,
            "ExplicitHashKey": explicit_hash_key,
            "SequenceNumberForOrdering": sequence_number_for_ordering,
        },
    )


async def put_multiple(hub, ctx, records: List, stream_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Writes multiple data records into a Kinesis data stream in a single call (also referred to as a PutRecords request). Use this operation to send data into the stream for data ingestion and processing.  Each PutRecords request can support up to 500 records. Each record in the request can be as large as 1 MiB, up to a limit of 5 MiB for the entire request, including partition keys. Each shard can support writes up to 1,000 records per second, up to a maximum data write total of 1 MiB per second. You must specify the name of the stream that captures, stores, and transports the data; and an array of request Records, with each record in the array requiring a partition key and data blob. The record size limit applies to the total size of the partition key and data blob. The data blob can be any type of data; for example, a segment from a log file, geographic/location data, website clickstream data, and so on. The partition key is used by Kinesis Data Streams as input to a hash function that maps the partition key and associated data to a specific shard. An MD5 hash function is used to map partition keys to 128-bit integer values and to map associated data records to shards. As a result of this hashing mechanism, all data records with the same partition key map to the same shard within the stream. For more information, see Adding Data to a Stream in the Amazon Kinesis Data Streams Developer Guide. Each record in the Records array may include an optional parameter, ExplicitHashKey, which overrides the partition key to shard mapping. This parameter allows a data producer to determine explicitly the shard where the record is stored. For more information, see Adding Multiple Records with PutRecords in the Amazon Kinesis Data Streams Developer Guide. The PutRecords response includes an array of response Records. Each record in the response array directly correlates with a record in the request array using natural ordering, from the top to the bottom of the request and response. The response Records array always includes the same number of records as the request array. The response Records array includes both successfully and unsuccessfully processed records. Kinesis Data Streams attempts to process all records in each PutRecords request. A single record failure does not stop the processing of subsequent records. As a result, PutRecords doesn't guarantee the ordering of records. If you need to read records in the same order they are written to the stream, use PutRecord instead of PutRecords, and write to the same shard. A successfully processed record includes ShardId and SequenceNumber values. The ShardId parameter identifies the shard in the stream where the record is stored. The SequenceNumber parameter is an identifier assigned to the put record, unique to all records in the stream. An unsuccessfully processed record includes ErrorCode and ErrorMessage values. ErrorCode reflects the type of error and can be one of the following values: ProvisionedThroughputExceededException or InternalFailure. ErrorMessage provides more detailed information about the ProvisionedThroughputExceededException exception including the account ID, stream name, and shard ID of the record that was throttled. For more information about partially successful responses, see Adding Multiple Records with PutRecords in the Amazon Kinesis Data Streams Developer Guide.  After you write a record to a stream, you cannot modify that record or its order within the stream.  By default, data records are accessible for 24 hours from the time that they are added to a stream. You can use IncreaseStreamRetentionPeriod or DecreaseStreamRetentionPeriod to modify this retention period.

    Args:
        records(List): The records associated with the request.
        stream_name(str): The stream name associated with the request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.record.put_multiple(
                ctx, records=value, stream_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.record.put_multiple records=value, stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="put_records",
        op_kwargs={"Records": records, "StreamName": stream_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(hub, ctx, transform_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts a task to estimate the quality of the transform.  When you provide label sets as examples of truth, Glue machine learning uses some of those examples to learn from them. The rest of the labels are used as a test to estimate quality. Returns a unique identifier for the run. You can call GetMLTaskRun to get more information about the stats of the EvaluationTaskRun.

    Args:
        transform_id(str): The unique identifier of the machine learning transform.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.ml.evaluation_task_run.start(ctx, transform_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.ml.evaluation_task_run.start transform_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="start_ml_evaluation_task_run",
        op_kwargs={"TransformId": transform_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    evaluation_id: str,
    ml_model_id: str,
    evaluation_data_source_id: str,
    evaluation_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Evaluation of an MLModel. An MLModel is evaluated on a set of observations associated to a DataSource. Like a DataSource for an MLModel, the DataSource for an Evaluation contains values for the Target Variable. The Evaluation compares the predicted result for each observation to the actual outcome and provides a summary so that you know how effective the MLModel functions on the test data. Evaluation generates a relevant performance metric, such as BinaryAUC, RegressionRMSE or MulticlassAvgFScore based on the corresponding MLModelType: BINARY, REGRESSION or MULTICLASS.   CreateEvaluation is an asynchronous operation. In response to CreateEvaluation, Amazon Machine Learning (Amazon ML) immediately returns and sets the evaluation status to PENDING. After the Evaluation is created and ready for use, Amazon ML sets the status to COMPLETED.  You can use the GetEvaluation operation to check progress of the evaluation during the creation operation.

    Args:
        evaluation_id(str): A user-supplied ID that uniquely identifies the Evaluation.
        evaluation_name(str, optional): A user-supplied name or description of the Evaluation. Defaults to None.
        ml_model_id(str): The ID of the MLModel to evaluate. The schema used in creating the MLModel must match the schema of the DataSource used in the Evaluation.
        evaluation_data_source_id(str): The ID of the DataSource for the evaluation. The schema of the DataSource must match the schema used to create the MLModel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.evaluation.create(
                ctx, evaluation_id=value, ml_model_id=value, evaluation_data_source_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.evaluation.create evaluation_id=value, ml_model_id=value, evaluation_data_source_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="create_evaluation",
        op_kwargs={
            "EvaluationId": evaluation_id,
            "EvaluationName": evaluation_name,
            "MLModelId": ml_model_id,
            "EvaluationDataSourceId": evaluation_data_source_id,
        },
    )


async def delete(hub, ctx, evaluation_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Assigns the DELETED status to an Evaluation, rendering it unusable. After invoking the DeleteEvaluation operation, you can use the GetEvaluation operation to verify that the status of the Evaluation changed to DELETED.  Caution: The results of the DeleteEvaluation operation are irreversible.

    Args:
        evaluation_id(str): A user-supplied ID that uniquely identifies the Evaluation to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.evaluation.delete(ctx, evaluation_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.evaluation.delete evaluation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="delete_evaluation",
        op_kwargs={"EvaluationId": evaluation_id},
    )


async def describe_all(
    hub,
    ctx,
    filter_variable: str = None,
    eq: str = None,
    gt: str = None,
    lt: str = None,
    ge: str = None,
    le: str = None,
    ne: str = None,
    prefix: str = None,
    sort_order: str = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of DescribeEvaluations that match the search criteria in the request.

    Args:
        filter_variable(str, optional): Use one of the following variable to filter a list of Evaluation objects:    CreatedAt - Sets the search criteria to the Evaluation creation date.    Status - Sets the search criteria to the Evaluation status.    Name - Sets the search criteria to the contents of Evaluation   Name.    IAMUser - Sets the search criteria to the user account that invoked an Evaluation.    MLModelId - Sets the search criteria to the MLModel that was evaluated.    DataSourceId - Sets the search criteria to the DataSource used in Evaluation.    DataUri - Sets the search criteria to the data file(s) used in Evaluation. The URL can identify either a file or an Amazon Simple Storage Solution (Amazon S3) bucket or directory.  . Defaults to None.
        eq(str, optional): The equal to operator. The Evaluation results will have FilterVariable values that exactly match the value specified with EQ. Defaults to None.
        gt(str, optional): The greater than operator. The Evaluation results will have FilterVariable values that are greater than the value specified with GT. Defaults to None.
        lt(str, optional): The less than operator. The Evaluation results will have FilterVariable values that are less than the value specified with LT. Defaults to None.
        ge(str, optional): The greater than or equal to operator. The Evaluation results will have FilterVariable values that are greater than or equal to the value specified with GE. . Defaults to None.
        le(str, optional): The less than or equal to operator. The Evaluation results will have FilterVariable values that are less than or equal to the value specified with LE. Defaults to None.
        ne(str, optional): The not equal to operator. The Evaluation results will have FilterVariable values not equal to the value specified with NE. Defaults to None.
        prefix(str, optional): A string that is found at the beginning of a variable, such as Name or Id. For example, an Evaluation could have the Name 2014-09-09-HolidayGiftMailer. To search for this Evaluation, select Name for the FilterVariable and any of the following strings for the Prefix:    2014-09   2014-09-09   2014-09-09-Holiday  . Defaults to None.
        sort_order(str, optional): A two-value parameter that determines the sequence of the resulting list of Evaluation.    asc - Arranges the list in ascending order (A-Z, 0-9).    dsc - Arranges the list in descending order (Z-A, 9-0).   Results are sorted by FilterVariable. Defaults to None.
        next_token(str, optional): The ID of the page in the paginated results. Defaults to None.
        limit(int, optional):  The maximum number of Evaluation to include in the result. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.evaluation.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.evaluation.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="describe_evaluations",
        op_kwargs={
            "FilterVariable": filter_variable,
            "EQ": eq,
            "GT": gt,
            "LT": lt,
            "GE": ge,
            "LE": le,
            "NE": ne,
            "Prefix": prefix,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "Limit": limit,
        },
    )


async def get(hub, ctx, evaluation_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns an Evaluation that includes metadata as well as the current status of the Evaluation.

    Args:
        evaluation_id(str): The ID of the Evaluation to retrieve. The evaluation of each MLModel is recorded and cataloged. The ID provides the means to access the information. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.evaluation.get(ctx, evaluation_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.evaluation.get evaluation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="get_evaluation",
        op_kwargs={"EvaluationId": evaluation_id},
    )


async def update(hub, ctx, evaluation_id: str, evaluation_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates the EvaluationName of an Evaluation. You can use the GetEvaluation operation to view the contents of the updated data element.

    Args:
        evaluation_id(str): The ID assigned to the Evaluation during creation.
        evaluation_name(str): A new user-supplied name or description of the Evaluation that will replace the current content. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.evaluation.update(
                ctx, evaluation_id=value, evaluation_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.evaluation.update evaluation_id=value, evaluation_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="update_evaluation",
        op_kwargs={"EvaluationId": evaluation_id, "EvaluationName": evaluation_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx, admin_account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables a Security Hub administrator account. Can only be called by the organization management account.

    Args:
        admin_account_id(str): The Amazon Web Services account identifier of the Security Hub administrator account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.organization.admin_account.disable(
                ctx, admin_account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.organization.admin_account.disable admin_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="disable_organization_admin_account",
        op_kwargs={"AdminAccountId": admin_account_id},
    )


async def enable(hub, ctx, admin_account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Designates the Security Hub administrator account for an organization. Can only be called by the organization management account.

    Args:
        admin_account_id(str): The Amazon Web Services account identifier of the account to designate as the Security Hub administrator account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.organization.admin_account.enable(
                ctx, admin_account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.organization.admin_account.enable admin_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="enable_organization_admin_account",
        op_kwargs={"AdminAccountId": admin_account_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the Security Hub administrator accounts. Can only be called by the organization management account.

    Args:
        max_results(int, optional): The maximum number of items to return in the response. Defaults to None.
        next_token(str, optional): The token that is required for pagination. On your first call to the ListOrganizationAdminAccounts operation, set the value of this parameter to NULL. For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.organization.admin_account.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.organization.admin_account.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="list_organization_admin_accounts",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    accept_language: str = None,
    provisioned_product_id: str = None,
    provisioned_product_name: str = None,
    output_keys: List = None,
    page_size: int = None,
    page_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This API takes either a ProvisonedProductId or a ProvisionedProductName, along with a list of one or more output keys, and responds with the key/value pairs of those outputs.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        provisioned_product_id(str, optional): The identifier of the provisioned product that you want the outputs from. Defaults to None.
        provisioned_product_name(str, optional): The name of the provisioned product that you want the outputs from. Defaults to None.
        output_keys(List, optional): The list of keys that the API should return with their values. If none are provided, the API will return all outputs of the provisioned product. Defaults to None.
        page_size(int, optional): The maximum number of items to return with this call. Defaults to None.
        page_token(str, optional): The page token for the next set of results. To retrieve the first set of results, use null. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioned_product.output.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioned_product.output.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="get_provisioned_product_outputs",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "ProvisionedProductId": provisioned_product_id,
            "ProvisionedProductName": provisioned_product_name,
            "OutputKeys": output_keys,
            "PageSize": page_size,
            "PageToken": page_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def meter(
    hub,
    ctx,
    product_code: str,
    timestamp: str,
    usage_dimension: str,
    usage_quantity: int = None,
    dry_run: bool = None,
    usage_allocations: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    API to emit metering records. For identical requests, the API is idempotent. It simply returns the metering record ID. MeterUsage is authenticated on the buyer's AWS account using credentials from the EC2 instance, ECS task, or EKS pod. MeterUsage can optionally include multiple usage allocations, to provide customers with usage data split into buckets by tags that you define (or allow the customer to define).

    Args:
        product_code(str): Product code is used to uniquely identify a product in AWS Marketplace. The product code should be the same as the one used during the publishing of a new product.
        timestamp(str): Timestamp, in UTC, for which the usage is being reported. Your application can meter usage for up to one hour in the past. Make sure the timestamp value is not before the start of the software usage.
        usage_dimension(str): It will be one of the fcp dimension name provided during the publishing of the product.
        usage_quantity(int, optional): Consumption value for the hour. Defaults to 0 if not specified. Defaults to None.
        dry_run(bool, optional): Checks whether you have the permissions required for the action, but does not make the request. If you have the permissions, the request returns DryRunOperation; otherwise, it returns UnauthorizedException. Defaults to false if not specified. Defaults to None.
        usage_allocations(List, optional): The set of UsageAllocations to submit. The sum of all UsageAllocation quantities must equal the UsageQuantity of the MeterUsage request, and each UsageAllocation must have a unique set of tags (include no tags). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.meteringmarketplace.usage.meter(
                ctx, product_code=value, timestamp=value, usage_dimension=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.meteringmarketplace.usage.meter product_code=value, timestamp=value, usage_dimension=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="meteringmarketplace",
        operation="meter_usage",
        op_kwargs={
            "ProductCode": product_code,
            "Timestamp": timestamp,
            "UsageDimension": usage_dimension,
            "UsageQuantity": usage_quantity,
            "DryRun": dry_run,
            "UsageAllocations": usage_allocations,
        },
    )


async def register(
    hub, ctx, product_code: str, public_key_version: int, nonce: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Paid container software products sold through AWS Marketplace must integrate with the AWS Marketplace Metering Service and call the RegisterUsage operation for software entitlement and metering. Free and BYOL products for Amazon ECS or Amazon EKS aren't required to call RegisterUsage, but you may choose to do so if you would like to receive usage data in your seller reports. The sections below explain the behavior of RegisterUsage. RegisterUsage performs two primary functions: metering and entitlement.    Entitlement: RegisterUsage allows you to verify that the customer running your paid software is subscribed to your product on AWS Marketplace, enabling you to guard against unauthorized use. Your container image that integrates with RegisterUsage is only required to guard against unauthorized use at container startup, as such a CustomerNotSubscribedException/PlatformNotSupportedException will only be thrown on the initial call to RegisterUsage. Subsequent calls from the same Amazon ECS task instance (e.g. task-id) or Amazon EKS pod will not throw a CustomerNotSubscribedException, even if the customer unsubscribes while the Amazon ECS task or Amazon EKS pod is still running.    Metering: RegisterUsage meters software use per ECS task, per hour, or per pod for Amazon EKS with usage prorated to the second. A minimum of 1 minute of usage applies to tasks that are short lived. For example, if a customer has a 10 node Amazon ECS or Amazon EKS cluster and a service configured as a Daemon Set, then Amazon ECS or Amazon EKS will launch a task on all 10 cluster nodes and the customer will be charged: (10 * hourly_rate). Metering for software use is automatically handled by the AWS Marketplace Metering Control Plane -- your software is not required to perform any metering specific actions, other than call RegisterUsage once for metering of software use to commence. The AWS Marketplace Metering Control Plane will also continue to bill customers for running ECS tasks and Amazon EKS pods, regardless of the customers subscription state, removing the need for your software to perform entitlement checks at runtime.

    Args:
        product_code(str): Product code is used to uniquely identify a product in AWS Marketplace. The product code should be the same as the one used during the publishing of a new product.
        public_key_version(int): Public Key Version provided by AWS Marketplace.
        nonce(str, optional): (Optional) To scope down the registration to a specific running software instance and guard against replay attacks. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.meteringmarketplace.usage.register(
                ctx, product_code=value, public_key_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.meteringmarketplace.usage.register product_code=value, public_key_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="meteringmarketplace",
        operation="register_usage",
        op_kwargs={
            "ProductCode": product_code,
            "PublicKeyVersion": public_key_version,
            "Nonce": nonce,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, domain_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    For operations that require confirmation that the email address for the registrant contact is valid, such as registering a new domain, this operation returns information about whether the registrant contact has responded. If you want us to resend the email, use the ResendContactReachabilityEmail operation.

    Args:
        domain_name(str, optional): The name of the domain for which you want to know whether the registrant contact has confirmed that the email address is valid. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.contact_reachability.status.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.contact_reachability.status.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="get_contact_reachability_status",
        op_kwargs={"domainName": domain_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, organization_id: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a group that can be used in Amazon WorkMail by calling the RegisterToWorkMail operation.

    Args:
        organization_id(str): The organization under which the group is to be created.
        name(str): The name of the group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.group.init.create(
                ctx, organization_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.group.init.create organization_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="create_group",
        op_kwargs={"OrganizationId": organization_id, "Name": name},
    )


async def delete(hub, ctx, organization_id: str, group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a group from Amazon WorkMail.

    Args:
        organization_id(str): The organization that contains the group.
        group_id(str): The identifier of the group to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.group.init.delete(
                ctx, organization_id=value, group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.group.init.delete organization_id=value, group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="delete_group",
        op_kwargs={"OrganizationId": organization_id, "GroupId": group_id},
    )


async def describe(hub, ctx, organization_id: str, group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the data available for the group.

    Args:
        organization_id(str): The identifier for the organization under which the group exists.
        group_id(str): The identifier for the group to be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.group.init.describe(
                ctx, organization_id=value, group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.group.init.describe organization_id=value, group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="describe_group",
        op_kwargs={"OrganizationId": organization_id, "GroupId": group_id},
    )


async def list_all(
    hub, ctx, organization_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns summaries of the organization's groups.

    Args:
        organization_id(str): The identifier for the organization under which the groups exist.
        next_token(str, optional): The token to use to retrieve the next page of results. The first call does not contain any tokens. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.group.init.list_all(ctx, organization_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.group.init.list_all organization_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="list_groups",
        op_kwargs={
            "OrganizationId": organization_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub, ctx, job_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the segment detection results of a Amazon Rekognition Video analysis started by StartSegmentDetection. Segment detection with Amazon Rekognition Video is an asynchronous operation. You start segment detection by calling StartSegmentDetection which returns a job identifier (JobId). When the segment detection operation finishes, Amazon Rekognition publishes a completion status to the Amazon Simple Notification Service topic registered in the initial call to StartSegmentDetection. To get the results of the segment detection operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. if so, call GetSegmentDetection and pass the job identifier (JobId) from the initial call of StartSegmentDetection.  GetSegmentDetection returns detected segments in an array (Segments) of SegmentDetection objects. Segments is sorted by the segment types specified in the SegmentTypes input parameter of StartSegmentDetection. Each element of the array includes the detected segment, the precentage confidence in the acuracy of the detected segment, the type of the segment, and the frame in which the segment was detected. Use SelectedSegmentTypes to find out the type of segment detection requested in the call to StartSegmentDetection. Use the MaxResults parameter to limit the number of segment detections returned. If there are more results than specified in MaxResults, the value of NextToken in the operation response contains a pagination token for getting the next set of results. To get the next page of results, call GetSegmentDetection and populate the NextToken request parameter with the token value returned from the previous call to GetSegmentDetection. For more information, see Detecting Video Segments in Stored Video in the Amazon Rekognition Developer Guide.

    Args:
        job_id(str): Job identifier for the text detection operation for which you want results returned. You get the job identifer from an initial call to StartSegmentDetection.
        max_results(int, optional): Maximum number of results to return per paginated call. The largest value you can specify is 1000. Defaults to None.
        next_token(str, optional): If the response is truncated, Amazon Rekognition Video returns this token that you can use in the subsequent request to retrieve the next set of text. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.segment_detection.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.segment_detection.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="get_segment_detection",
        op_kwargs={"JobId": job_id, "MaxResults": max_results, "NextToken": next_token},
    )


async def start(
    hub,
    ctx,
    video: Dict,
    segment_types: List,
    client_request_token: str = None,
    notification_channel: Dict = None,
    job_tag: str = None,
    filters: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts asynchronous detection of segment detection in a stored video. Amazon Rekognition Video can detect segments in a video stored in an Amazon S3 bucket. Use Video to specify the bucket name and the filename of the video. StartSegmentDetection returns a job identifier (JobId) which you use to get the results of the operation. When segment detection is finished, Amazon Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic that you specify in NotificationChannel. You can use the Filters (StartSegmentDetectionFilters) input parameter to specify the minimum detection confidence returned in the response. Within Filters, use ShotFilter (StartShotDetectionFilter) to filter detected shots. Use TechnicalCueFilter (StartTechnicalCueDetectionFilter) to filter technical cues.  To get the results of the segment detection operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. if so, call GetSegmentDetection and pass the job identifier (JobId) from the initial call to StartSegmentDetection.  For more information, see Detecting Video Segments in Stored Video in the Amazon Rekognition Developer Guide.

    Args:
        video(Dict): Video file stored in an Amazon S3 bucket. Amazon Rekognition video start operations such as StartLabelDetection use Video to specify a video for analysis. The supported file formats are .mp4, .mov and .avi.
        client_request_token(str, optional): Idempotent token used to identify the start request. If you use the same token with multiple StartSegmentDetection requests, the same JobId is returned. Use ClientRequestToken to prevent the same job from being accidently started more than once. . Defaults to None.
        notification_channel(Dict, optional): The ARN of the Amazon SNS topic to which you want Amazon Rekognition Video to publish the completion status of the segment detection operation. Defaults to None.
        job_tag(str, optional): An identifier you specify that's returned in the completion notification that's published to your Amazon Simple Notification Service topic. For example, you can use JobTag to group related jobs and identify them in the completion notification. Defaults to None.
        filters(Dict, optional): Filters for technical cue or shot detection. Defaults to None.
        segment_types(List): An array of segment types to detect in the video. Valid values are TECHNICAL_CUE and SHOT.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.segment_detection.start(
                ctx, video=value, segment_types=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.segment_detection.start video=value, segment_types=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="start_segment_detection",
        op_kwargs={
            "Video": video,
            "ClientRequestToken": client_request_token,
            "NotificationChannel": notification_channel,
            "JobTag": job_tag,
            "Filters": filters,
            "SegmentTypes": segment_types,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    role_arn: str,
    resources_vpc_config: Dict,
    version: str = None,
    kubernetes_network_config: Dict = None,
    logging: Dict = None,
    client_request_token: str = None,
    tags: Dict = None,
    encryption_config: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon EKS control plane.  The Amazon EKS control plane consists of control plane instances that run the Kubernetes software, such as etcd and the API server. The control plane runs in an account managed by Amazon Web Services, and the Kubernetes API is exposed via the Amazon EKS API server endpoint. Each Amazon EKS cluster control plane is single-tenant and unique and runs on its own set of Amazon EC2 instances. The cluster control plane is provisioned across multiple Availability Zones and fronted by an Elastic Load Balancing Network Load Balancer. Amazon EKS also provisions elastic network interfaces in your VPC subnets to provide connectivity from the control plane instances to the nodes (for example, to support kubectl exec, logs, and proxy data flows). Amazon EKS nodes run in your Amazon Web Services account and connect to your cluster's control plane via the Kubernetes API server endpoint and a certificate file that is created for your cluster. Cluster creation typically takes several minutes. After you create an Amazon EKS cluster, you must configure your Kubernetes tooling to communicate with the API server and launch nodes into your cluster. For more information, see Managing Cluster Authentication and Launching Amazon EKS nodes in the Amazon EKS User Guide.

    Args:
        name(str): The unique name to give to your cluster.
        version(str, optional): The desired Kubernetes version for your cluster. If you don't specify a value here, the latest version available in Amazon EKS is used. Defaults to None.
        role_arn(str): The Amazon Resource Name (ARN) of the IAM role that provides permissions for the Kubernetes control plane to make calls to Amazon Web Services API operations on your behalf. For more information, see Amazon EKS Service IAM Role in the  Amazon EKS User Guide .
        resources_vpc_config(Dict): The VPC configuration used by the cluster control plane. Amazon EKS VPC resources have specific requirements to work properly with Kubernetes. For more information, see Cluster VPC Considerations and Cluster Security Group Considerations in the Amazon EKS User Guide. You must specify at least two subnets. You can specify up to five security groups, but we recommend that you use a dedicated security group for your cluster control plane.
        kubernetes_network_config(Dict, optional): The Kubernetes network configuration for the cluster. Defaults to None.
        logging(Dict, optional): Enable or disable exporting the Kubernetes control plane logs for your cluster to CloudWatch Logs. By default, cluster control plane logs aren't exported to CloudWatch Logs. For more information, see Amazon EKS Cluster control plane logs in the  Amazon EKS User Guide .  CloudWatch Logs ingestion, archive storage, and data scanning rates apply to exported control plane logs. For more information, see CloudWatch Pricing. . Defaults to None.
        client_request_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.
        tags(Dict, optional): The metadata to apply to the cluster to assist with categorization and organization. Each tag consists of a key and an optional value, both of which you define. Defaults to None.
        encryption_config(List, optional): The encryption configuration for the cluster. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.cluster.init.create(
                ctx, name=value, role_arn=value, resources_vpc_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.cluster.init.create name=value, role_arn=value, resources_vpc_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="create_cluster",
        op_kwargs={
            "name": name,
            "version": version,
            "roleArn": role_arn,
            "resourcesVpcConfig": resources_vpc_config,
            "kubernetesNetworkConfig": kubernetes_network_config,
            "logging": logging,
            "clientRequestToken": client_request_token,
            "tags": tags,
            "encryptionConfig": encryption_config,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the Amazon EKS cluster control plane. If you have active services in your cluster that are associated with a load balancer, you must delete those services before deleting the cluster so that the load balancers are deleted properly. Otherwise, you can have orphaned resources in your VPC that prevent you from being able to delete the VPC. For more information, see Deleting a Cluster in the Amazon EKS User Guide. If you have managed node groups or Fargate profiles attached to the cluster, you must delete them first. For more information, see DeleteNodegroup and DeleteFargateProfile.

    Args:
        name(str): The name of the cluster to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.cluster.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.cluster.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="eks", operation="delete_cluster", op_kwargs={"name": name}
    )


async def describe(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns descriptive information about an Amazon EKS cluster. The API server endpoint and certificate authority data returned by this operation are required for kubelet and kubectl to communicate with your Kubernetes API server. For more information, see Create a kubeconfig for Amazon EKS.  The API server endpoint and certificate authority data aren't available until the cluster reaches the ACTIVE state.

    Args:
        name(str): The name of the cluster to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.cluster.init.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.cluster.init.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="eks", operation="describe_cluster", op_kwargs={"name": name}
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the Amazon EKS clusters in your Amazon Web Services account in the specified Region.

    Args:
        max_results(int, optional): The maximum number of cluster results returned by ListClusters in paginated output. When you use this parameter, ListClusters returns only maxResults results in a single page along with a nextToken response element. You can see the remaining results of the initial request by sending another ListClusters request with the returned nextToken value. This value can be between 1 and 100. If you don't use this parameter, ListClusters returns up to 100 results and a nextToken value if applicable. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated ListClusters request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.  This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.cluster.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.cluster.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="list_clusters",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put(
    hub,
    ctx,
    job_id: str,
    current_revision: Dict = None,
    continuation_token: str = None,
    execution_details: Dict = None,
    output_variables: Dict = None,
) -> None:
    r"""
    **Autogenerated function**

    Represents the success of a job as returned to the pipeline by a job worker. Used for custom actions only.

    Args:
        job_id(str): The unique system-generated ID of the job that succeeded. This is the same ID returned from PollForJobs.
        current_revision(Dict, optional): The ID of the current revision of the artifact successfully worked on by the job. Defaults to None.
        continuation_token(str, optional): A token generated by a job worker, such as an AWS CodeDeploy deployment ID, that a successful job provides to identify a custom action in progress. Future jobs use this token to identify the running instance of the action. It can be reused to return more information about the progress of the custom action. When the action is complete, no continuation token should be supplied. Defaults to None.
        execution_details(Dict, optional): The execution details of the successful job, such as the actions taken by the job worker. Defaults to None.
        output_variables(Dict, optional): Key-value pairs produced as output by a job worker that can be made available to a downstream action configuration. outputVariables can be included only when there is no continuation token on the request. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.job.success_result.put(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.job.success_result.put job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="put_job_success_result",
        op_kwargs={
            "jobId": job_id,
            "currentRevision": current_revision,
            "continuationToken": continuation_token,
            "executionDetails": execution_details,
            "outputVariables": output_variables,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    cluster_version: str = None,
    cluster_parameter_group_family: str = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns descriptions of the available Amazon Redshift cluster versions. You can call this operation even before creating any clusters to learn more about the Amazon Redshift versions. For more information about managing clusters, go to Amazon Redshift Clusters in the Amazon Redshift Cluster Management Guide.

    Args:
        cluster_version(str, optional): The specific cluster version to return. Example: 1.0 . Defaults to None.
        cluster_parameter_group_family(str, optional): The name of a specific cluster parameter group family to return details for. Constraints:   Must be 1 to 255 alphanumeric characters   First character must be a letter   Cannot end with a hyphen or contain two consecutive hyphens  . Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 100  Constraints: minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeClusterVersions request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.version.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.version.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_cluster_versions",
        op_kwargs={
            "ClusterVersion": cluster_version,
            "ClusterParameterGroupFamily": cluster_parameter_group_family,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    customer_gateway_arn: str,
    global_network_id: str,
    device_id: str,
    link_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a customer gateway with a device and optionally, with a link. If you specify a link, it must be associated with the specified device.  You can only associate customer gateways that are connected to a VPN attachment on a transit gateway. The transit gateway must be registered in your global network. When you register a transit gateway, customer gateways that are connected to the transit gateway are automatically included in the global network. To list customer gateways that are connected to a transit gateway, use the DescribeVpnConnections EC2 API and filter by transit-gateway-id. You cannot associate a customer gateway with more than one device and link.

    Args:
        customer_gateway_arn(str): The Amazon Resource Name (ARN) of the customer gateway. For more information, see Resources Defined by Amazon EC2.
        global_network_id(str): The ID of the global network.
        device_id(str): The ID of the device.
        link_id(str, optional): The ID of the link. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.customer_gateway.init.associate(
                ctx, customer_gateway_arn=value, global_network_id=value, device_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.customer_gateway.init.associate customer_gateway_arn=value, global_network_id=value, device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="associate_customer_gateway",
        op_kwargs={
            "CustomerGatewayArn": customer_gateway_arn,
            "GlobalNetworkId": global_network_id,
            "DeviceId": device_id,
            "LinkId": link_id,
        },
    )


async def disassociate(
    hub, ctx, global_network_id: str, customer_gateway_arn: str
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a customer gateway from a device and a link.

    Args:
        global_network_id(str): The ID of the global network.
        customer_gateway_arn(str): The Amazon Resource Name (ARN) of the customer gateway. For more information, see Resources Defined by Amazon EC2.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.customer_gateway.init.disassociate(
                ctx, global_network_id=value, customer_gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.customer_gateway.init.disassociate global_network_id=value, customer_gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="disassociate_customer_gateway",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "CustomerGatewayArn": customer_gateway_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub, ctx, filters: Dict, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of Jobs. Use the JobsID and fromDate and toData filters to limit which jobs are returned. The response is sorted by creationDataTime - latest date first. Jobs are normaly created by the StartTest, StartCutover, and TerminateTargetInstances APIs. Jobs are also created by DiagnosticLaunch and TerminateDiagnosticInstances, which are APIs available only to *Support* and only used in response to relevant support tickets.

    Args:
        filters(Dict): Request to describe Job log filters.
        max_results(int, optional): Request to describe Job log by max results. Defaults to None.
        next_token(str, optional): Request to describe Job logby next token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.jobs.describe(ctx, filters=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.jobs.describe filters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="describe_jobs",
        op_kwargs={
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def put_multiple(
    hub,
    ctx,
    cluster: str,
    capacity_providers: List,
    default_capacity_provider_strategy: List,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the available capacity providers and the default capacity provider strategy for a cluster. You must specify both the available capacity providers and a default capacity provider strategy for the cluster. If the specified cluster has existing capacity providers associated with it, you must specify all existing capacity providers in addition to any new ones you want to add. Any existing capacity providers associated with a cluster that are omitted from a PutClusterCapacityProviders API call will be disassociated with the cluster. You can only disassociate an existing capacity provider from a cluster if it's not being used by any existing tasks. When creating a service or running a task on a cluster, if no capacity provider or launch type is specified, then the cluster's default capacity provider strategy is used. It is recommended to define a default capacity provider strategy for your cluster, however you may specify an empty array ([]) to bypass defining a default strategy.

    Args:
        cluster(str): The short name or full Amazon Resource Name (ARN) of the cluster to modify the capacity provider settings for. If you do not specify a cluster, the default cluster is assumed.
        capacity_providers(List): The name of one or more capacity providers to associate with the cluster. If specifying a capacity provider that uses an Auto Scaling group, the capacity provider must already be created. New capacity providers can be created with the CreateCapacityProvider API operation. To use a Fargate capacity provider, specify either the FARGATE or FARGATE_SPOT capacity providers. The Fargate capacity providers are available to all accounts and only need to be associated with a cluster to be used.
        default_capacity_provider_strategy(List): The capacity provider strategy to use by default for the cluster. When creating a service or running a task on a cluster, if no capacity provider or launch type is specified then the default capacity provider strategy for the cluster is used. A capacity provider strategy consists of one or more capacity providers along with the base and weight to assign to them. A capacity provider must be associated with the cluster to be used in a capacity provider strategy. The PutClusterCapacityProviders API is used to associate a capacity provider with a cluster. Only capacity providers with an ACTIVE or UPDATING status can be used. If specifying a capacity provider that uses an Auto Scaling group, the capacity provider must already be created. New capacity providers can be created with the CreateCapacityProvider API operation. To use a Fargate capacity provider, specify either the FARGATE or FARGATE_SPOT capacity providers. The Fargate capacity providers are available to all accounts and only need to be associated with a cluster to be used.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.cluster.capacity_provider.put_multiple(
                ctx,
                cluster=value,
                capacity_providers=value,
                default_capacity_provider_strategy=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.cluster.capacity_provider.put_multiple cluster=value, capacity_providers=value, default_capacity_provider_strategy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="put_cluster_capacity_providers",
        op_kwargs={
            "cluster": cluster,
            "capacityProviders": capacity_providers,
            "defaultCapacityProviderStrategy": default_capacity_provider_strategy,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "regex_pattern_set"


async def create(
    hub,
    ctx,
    name: str,
    scope: str,
    regular_expression_list: List,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a RegexPatternSet, which you reference in a RegexPatternSetReferenceStatement, to have WAF inspect a web request component for the specified patterns.

    Args:
        name(str): The name of the set. You cannot change the name after you create the set.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        description(str, optional): A description of the set that helps with identification. . Defaults to None.
        regular_expression_list(List): Array of regular expression strings. .
        tags(List, optional): An array of key:value pairs to associate with the resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.regex_pattern_set_.create(
                ctx, name=value, scope=value, regular_expression_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.regex_pattern_set.create name=value, scope=value, regular_expression_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="create_regex_pattern_set",
        op_kwargs={
            "Name": name,
            "Scope": scope,
            "Description": description,
            "RegularExpressionList": regular_expression_list,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, name: str, scope: str, id_: str, lock_token: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified RegexPatternSet.

    Args:
        name(str): The name of the set. You cannot change the name after you create the set.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        id_(str): A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
        lock_token(str): A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.regex_pattern_set_.delete(
                ctx, name=value, scope=value, id_=value, lock_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.regex_pattern_set.delete name=value, scope=value, id_=value, lock_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="delete_regex_pattern_set",
        op_kwargs={"Name": name, "Scope": scope, "Id": id_, "LockToken": lock_token},
    )


async def get(hub, ctx, name: str, scope: str, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the specified RegexPatternSet.

    Args:
        name(str): The name of the set. You cannot change the name after you create the set.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        id_(str): A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.regex_pattern_set_.get(
                ctx, name=value, scope=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.regex_pattern_set.get name=value, scope=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="get_regex_pattern_set",
        op_kwargs={"Name": name, "Scope": scope, "Id": id_},
    )


async def list_all(
    hub, ctx, scope: str, next_marker: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an array of RegexPatternSetSummary objects for the regex pattern sets that you manage.

    Args:
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        next_marker(str, optional): When you request a list of objects with a Limit setting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns a NextMarker value in the response. To retrieve the next batch of objects, provide the marker from the prior call in your next request. Defaults to None.
        limit(int, optional): The maximum number of objects that you want WAF to return for this request. If more objects are available, in the response, WAF provides a NextMarker value that you can use in a subsequent call to get the next batch of objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.regex_pattern_set_.list_all(ctx, scope=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.regex_pattern_set.list_all scope=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="list_regex_pattern_sets",
        op_kwargs={"Scope": scope, "NextMarker": next_marker, "Limit": limit},
    )


async def update(
    hub,
    ctx,
    name: str,
    scope: str,
    id_: str,
    regular_expression_list: List,
    lock_token: str,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified RegexPatternSet.  This operation completely replaces the mutable specifications that you already have for the regex pattern set with the ones that you provide to this call. To modify the regex pattern set, retrieve it by calling GetRegexPatternSet, update the settings as needed, and then provide the complete regex pattern set specification to this call.

    Args:
        name(str): The name of the set. You cannot change the name after you create the set.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        id_(str): A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
        description(str, optional): A description of the set that helps with identification. . Defaults to None.
        regular_expression_list(List): .
        lock_token(str): A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.regex_pattern_set_.update(
                ctx,
                name=value,
                scope=value,
                id_=value,
                regular_expression_list=value,
                lock_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.regex_pattern_set.update name=value, scope=value, id_=value, regular_expression_list=value, lock_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="update_regex_pattern_set",
        op_kwargs={
            "Name": name,
            "Scope": scope,
            "Id": id_,
            "Description": description,
            "RegularExpressionList": regular_expression_list,
            "LockToken": lock_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, model_id: str, model_type: str, model_version_number: str, status: str
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the status of a model version. You can perform the following status updates:   Change the TRAINING_COMPLETE status to ACTIVE.   Change ACTIVEto INACTIVE.

    Args:
        model_id(str): The model ID of the model version to update.
        model_type(str): The model type.
        model_version_number(str): The model version number.
        status(str): The model version status.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.model.version.status.update(
                ctx, model_id=value, model_type=value, model_version_number=value, status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.model.version.status.update model_id=value, model_type=value, model_version_number=value, status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="update_model_version_status",
        op_kwargs={
            "modelId": model_id,
            "modelType": model_type,
            "modelVersionNumber": model_version_number,
            "status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    subnet_id: str,
    ssh_key: str,
    iam_role_arn: str,
    subscription_type: str,
    eni_ip: str = None,
    external_id: str = None,
    client_token: str = None,
    syslog_ip: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Creates an uninitialized HSM instance. There is an upfront fee charged for each HSM instance that you create with the CreateHsm operation. If you accidentally provision an HSM and want to request a refund, delete the instance using the DeleteHsm operation, go to the AWS Support Center, create a new case, and select Account and Billing Support.  It can take up to 20 minutes to create and provision an HSM. You can monitor the status of the HSM with the DescribeHsm operation. The HSM is ready to be initialized when the status changes to RUNNING.

    Args:
        subnet_id(str): The identifier of the subnet in your VPC in which to place the HSM.
        ssh_key(str): The SSH public key to install on the HSM.
        eni_ip(str, optional): The IP address to assign to the HSM's ENI. If an IP address is not specified, an IP address will be randomly chosen from the CIDR range of the subnet. Defaults to None.
        iam_role_arn(str): The ARN of an IAM role to enable the AWS CloudHSM service to allocate an ENI on your behalf.
        external_id(str, optional): The external ID from IamRoleArn, if present. Defaults to None.
        subscription_type(str): Specifies the type of subscription for the HSM.    PRODUCTION - The HSM is being used in a production environment.    TRIAL - The HSM is being used in a product trial.  .
        client_token(str, optional): A user-defined token to ensure idempotence. Subsequent calls to this operation with the same token will be ignored. Defaults to None.
        syslog_ip(str, optional): The IP address for the syslog monitoring server. The AWS CloudHSM service only supports one syslog monitoring server. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.hsm.create(
                ctx, subnet_id=value, ssh_key=value, iam_role_arn=value, subscription_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.hsm.create subnet_id=value, ssh_key=value, iam_role_arn=value, subscription_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="create_hsm",
        op_kwargs={
            "SubnetId": subnet_id,
            "SshKey": ssh_key,
            "EniIp": eni_ip,
            "IamRoleArn": iam_role_arn,
            "ExternalId": external_id,
            "SubscriptionType": subscription_type,
            "ClientToken": client_token,
            "SyslogIp": syslog_ip,
        },
    )


async def delete(hub, ctx, hsm_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Deletes an HSM. After completion, this operation cannot be undone and your key material cannot be recovered.

    Args:
        hsm_arn(str): The ARN of the HSM to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.hsm.delete(ctx, hsm_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.hsm.delete hsm_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="delete_hsm",
        op_kwargs={"HsmArn": hsm_arn},
    )


async def describe(
    hub, ctx, hsm_arn: str = None, hsm_serial_number: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Retrieves information about an HSM. You can identify the HSM by its ARN or its serial number.

    Args:
        hsm_arn(str, optional): The ARN of the HSM. Either the HsmArn or the SerialNumber parameter must be specified. Defaults to None.
        hsm_serial_number(str, optional): The serial number of the HSM. Either the HsmArn or the HsmSerialNumber parameter must be specified. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.hsm.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.hsm.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="describe_hsm",
        op_kwargs={"HsmArn": hsm_arn, "HsmSerialNumber": hsm_serial_number},
    )


async def modify(
    hub,
    ctx,
    hsm_arn: str,
    subnet_id: str = None,
    eni_ip: str = None,
    iam_role_arn: str = None,
    external_id: str = None,
    syslog_ip: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Modifies an HSM.  This operation can result in the HSM being offline for up to 15 minutes while the AWS CloudHSM service is reconfigured. If you are modifying a production HSM, you should ensure that your AWS CloudHSM service is configured for high availability, and consider executing this operation during a maintenance window.

    Args:
        hsm_arn(str): The ARN of the HSM to modify.
        subnet_id(str, optional): The new identifier of the subnet that the HSM is in. The new subnet must be in the same Availability Zone as the current subnet. Defaults to None.
        eni_ip(str, optional): The new IP address for the elastic network interface (ENI) attached to the HSM. If the HSM is moved to a different subnet, and an IP address is not specified, an IP address will be randomly chosen from the CIDR range of the new subnet. Defaults to None.
        iam_role_arn(str, optional): The new IAM role ARN. Defaults to None.
        external_id(str, optional): The new external ID. Defaults to None.
        syslog_ip(str, optional): The new IP address for the syslog monitoring server. The AWS CloudHSM service only supports one syslog monitoring server. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.hsm.modify(ctx, hsm_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.hsm.modify hsm_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="modify_hsm",
        op_kwargs={
            "HsmArn": hsm_arn,
            "SubnetId": subnet_id,
            "EniIp": eni_ip,
            "IamRoleArn": iam_role_arn,
            "ExternalId": external_id,
            "SyslogIp": syslog_ip,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    readiness_check_name: str,
    resource_identifier: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns detailed information about the status of an individual resource within a Readiness Check's Resource Set.

    Args:
        max_results(int, optional): Upper bound on number of records to return. Defaults to None.
        next_token(str, optional): A token used to resume pagination from the end of a previous request. Defaults to None.
        readiness_check_name(str): The ReadinessCheck to get.
        resource_identifier(str): The resource ARN or component Id to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_readiness.readiness_check.resource_status.get(
                ctx, readiness_check_name=value, resource_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_readiness.readiness_check.resource_status.get readiness_check_name=value, resource_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-readiness",
        operation="get_readiness_check_resource_status",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "ReadinessCheckName": readiness_check_name,
            "ResourceIdentifier": resource_identifier,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, detectors: List) -> Dict:
    r"""
    **Autogenerated function**

    Updates the state, variable values, and timer settings of one or more detectors (instances) of a specified detector model.

    Args:
        detectors(List): The list of detectors (instances) to update, along with the values to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent_data.update_detector.batch(ctx, detectors=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent_data.update_detector.batch detectors=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents-data",
        operation="batch_update_detector",
        op_kwargs={"detectors": detectors},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, workbook_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     The ListTables API allows you to retrieve a list of all the tables in a workbook.

    Args:
        workbook_id(str): The ID of the workbook whose tables are being retrieved.  If a workbook with the specified id could not be found, this API throws ResourceNotFoundException. .
        max_results(int, optional): The maximum number of tables to return in each page of the results. Defaults to None.
        next_token(str, optional):  This parameter is optional. If a nextToken is not specified, the API returns the first page of data.   Pagination tokens expire after 1 hour. If you use a token that was returned more than an hour back, the API will throw ValidationException. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.honeycode.table.init.list_all(ctx, workbook_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.honeycode.table.init.list_all workbook_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="honeycode",
        operation="list_tables",
        op_kwargs={
            "workbookId": workbook_id,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def deregister(
    hub, ctx, dry_run: bool = None, instance_tag_attribute: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    c Deregisters tag keys to prevent tags that have the specified tag keys from being included in scheduled event notifications for resources in the Region.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_tag_attribute(Dict, optional): Information about the tag keys to deregister. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.event.notification_attribute.deregister(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.event.notification_attribute.deregister
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="deregister_instance_event_notification_attributes",
        op_kwargs={"DryRun": dry_run, "InstanceTagAttribute": instance_tag_attribute},
    )


async def describe_all(hub, ctx, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes the tag keys that are registered to appear in scheduled event notifications for resources in the current Region.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.event.notification_attribute.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.event.notification_attribute.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_instance_event_notification_attributes",
        op_kwargs={"DryRun": dry_run},
    )


async def register(
    hub, ctx, dry_run: bool = None, instance_tag_attribute: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Registers a set of tag keys to include in scheduled event notifications for your resources.  To remove tags, use .

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_tag_attribute(Dict, optional): Information about the tag keys to register. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.event.notification_attribute.register(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.event.notification_attribute.register
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="register_instance_event_notification_attributes",
        op_kwargs={"DryRun": dry_run, "InstanceTagAttribute": instance_tag_attribute},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def admin(
    hub,
    ctx,
    user_pool_id: str,
    username: str,
    user_attributes: List = None,
    validation_data: List = None,
    temporary_password: str = None,
    force_alias_creation: bool = None,
    message_action: str = None,
    desired_delivery_mediums: List = None,
    client_metadata: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new user in the specified user pool. If MessageAction is not set, the default is to send a welcome message via email or phone (SMS).  This action might generate an SMS text message. Starting June 1, 2021, U.S. telecom carriers require that you register an origination phone number before you can send SMS messages to U.S. phone numbers. If you use SMS text messages in Amazon Cognito, you must register a phone number with Amazon Pinpoint. Cognito will use the the registered number automatically. Otherwise, Cognito users that must receive SMS messages might be unable to sign up, activate their accounts, or sign in. If you have never used SMS text messages with Amazon Cognito or any other Amazon Web Service, Amazon SNS might place your account in SMS sandbox. In  sandbox mode , you’ll have limitations, such as sending messages to only verified phone numbers. After testing in the sandbox environment, you can move out of the SMS sandbox and into production. For more information, see  SMS message settings for Cognito User Pools in the Amazon Cognito Developer Guide.   This message is based on a template that you configured in your call to create or update a user pool. This template includes your custom sign-up instructions and placeholders for user name and temporary password. Alternatively, you can call AdminCreateUser with “SUPPRESS” for the MessageAction parameter, and Amazon Cognito will not send any email.  In either case, the user will be in the FORCE_CHANGE_PASSWORD state until they sign in and change their password.  AdminCreateUser requires developer credentials.

    Args:
        user_pool_id(str): The user pool ID for the user pool where the user will be created.
        username(str): The username for the user. Must be unique within the user pool. Must be a UTF-8 string between 1 and 128 characters. After the user is created, the username cannot be changed.
        user_attributes(List, optional): An array of name-value pairs that contain user attributes and attribute values to be set for the user to be created. You can create a user without specifying any attributes other than Username. However, any attributes that you specify as required (when creating a user pool or in the Attributes tab of the console) must be supplied either by you (in your call to AdminCreateUser) or by the user (when he or she signs up in response to your welcome message). For custom attributes, you must prepend the custom: prefix to the attribute name. To send a message inviting the user to sign up, you must specify the user's email address or phone number. This can be done in your call to AdminCreateUser or in the Users tab of the Amazon Cognito console for managing your user pools. In your call to AdminCreateUser, you can set the email_verified attribute to True, and you can set the phone_number_verified attribute to True. (You can also do this by calling AdminUpdateUserAttributes.)    email: The email address of the user to whom the message that contains the code and username will be sent. Required if the email_verified attribute is set to True, or if "EMAIL" is specified in the DesiredDeliveryMediums parameter.    phone_number: The phone number of the user to whom the message that contains the code and username will be sent. Required if the phone_number_verified attribute is set to True, or if "SMS" is specified in the DesiredDeliveryMediums parameter.  . Defaults to None.
        validation_data(List, optional): The user's validation data. This is an array of name-value pairs that contain user attributes and attribute values that you can use for custom validation, such as restricting the types of user accounts that can be registered. For example, you might choose to allow or disallow user sign-up based on the user's domain. To configure custom validation, you must create a Pre Sign-up Lambda trigger for the user pool as described in the Amazon Cognito Developer Guide. The Lambda trigger receives the validation data and uses it in the validation process. The user's validation data is not persisted. Defaults to None.
        temporary_password(str, optional): The user's temporary password. This password must conform to the password policy that you specified when you created the user pool. The temporary password is valid only once. To complete the Admin Create User flow, the user must enter the temporary password in the sign-in page along with a new password to be used in all future sign-ins. This parameter is not required. If you do not specify a value, Amazon Cognito generates one for you. The temporary password can only be used until the user account expiration limit that you specified when you created the user pool. To reset the account after that time limit, you must call AdminCreateUser again, specifying "RESEND" for the MessageAction parameter. Defaults to None.
        force_alias_creation(bool, optional): This parameter is only used if the phone_number_verified or email_verified attribute is set to True. Otherwise, it is ignored. If this parameter is set to True and the phone number or email address specified in the UserAttributes parameter already exists as an alias with a different user, the API call will migrate the alias from the previous user to the newly created user. The previous user will no longer be able to log in using that alias. If this parameter is set to False, the API throws an AliasExistsException error if the alias already exists. The default value is False. Defaults to None.
        message_action(str, optional): Set to "RESEND" to resend the invitation message to a user that already exists and reset the expiration limit on the user's account. Set to "SUPPRESS" to suppress sending the message. Only one value can be specified. Defaults to None.
        desired_delivery_mediums(List, optional): Specify "EMAIL" if email will be used to send the welcome message. Specify "SMS" if the phone number will be used. The default value is "SMS". More than one value can be specified. Defaults to None.
        client_metadata(Dict, optional): A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.  You create custom workflows by assigning Lambda functions to user pool triggers. When you use the AdminCreateUser API action, Amazon Cognito invokes the function that is assigned to the pre sign-up trigger. When Amazon Cognito invokes this function, it passes a JSON payload, which the function receives as input. This payload contains a clientMetadata attribute, which provides the data that you assigned to the ClientMetadata parameter in your AdminCreateUser request. In your function code in Lambda, you can process the clientMetadata value to enhance your workflow for your specific needs. For more information, see Customizing User Pool Workflows with Lambda Triggers in the Amazon Cognito Developer Guide.  Take the following limitations into consideration when you use the ClientMetadata parameter:   Amazon Cognito does not store the ClientMetadata value. This data is available only to Lambda triggers that are assigned to a user pool to support custom workflows. If your user pool configuration does not include triggers, the ClientMetadata parameter serves no purpose.   Amazon Cognito does not validate the ClientMetadata value.   Amazon Cognito does not encrypt the the ClientMetadata value, so don't use it to provide sensitive information.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.create_user.admin(
                ctx, user_pool_id=value, username=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.create_user.admin user_pool_id=value, username=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="admin_create_user",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "Username": username,
            "UserAttributes": user_attributes,
            "ValidationData": validation_data,
            "TemporaryPassword": temporary_password,
            "ForceAliasCreation": force_alias_creation,
            "MessageAction": message_action,
            "DesiredDeliveryMediums": desired_delivery_mediums,
            "ClientMetadata": client_metadata,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def get(hub, ctx, stack_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the stack policy for a specified stack. If a stack doesn't have a policy, a null value is returned.

    Args:
        stack_name(str): The name or unique stack ID that is associated with the stack whose policy you want to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.policy.get(ctx, stack_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.policy.get stack_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="get_stack_policy",
        op_kwargs={"StackName": stack_name},
    )


async def set_(
    hub,
    ctx,
    stack_name: str,
    stack_policy_body: str = None,
    stack_policy_url: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Sets a stack policy for a specified stack.

    Args:
        stack_name(str): The name or unique stack ID that you want to associate a policy with.
        stack_policy_body(str, optional): Structure containing the stack policy body. For more information, go to  Prevent Updates to Stack Resources in the CloudFormation User Guide. You can specify either the StackPolicyBody or the StackPolicyURL parameter, but not both. Defaults to None.
        stack_policy_url(str, optional): Location of a file containing the stack policy. The URL must point to a policy (maximum size: 16 KB) located in an S3 bucket in the same Region as the stack. You can specify either the StackPolicyBody or the StackPolicyURL parameter, but not both. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.policy.set(ctx, stack_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.policy.set stack_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="set_stack_policy",
        op_kwargs={
            "StackName": stack_name,
            "StackPolicyBody": stack_policy_body,
            "StackPolicyURL": stack_policy_url,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified DataBrew job.

    Args:
        name(str): The name of the job to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.job.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.job.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="databrew", operation="delete_job", op_kwargs={"Name": name}
    )


async def describe(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the definition of a specific DataBrew job.

    Args:
        name(str): The name of the job to be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.job.init.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.job.init.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="databrew", operation="describe_job", op_kwargs={"Name": name}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    max_results: int = None,
    next_token: str = None,
    order: str = None,
    queue: str = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve a JSON array of up to twenty of your most recently created jobs. This array includes in-process, completed, and errored jobs. This will return the jobs themselves, not just a list of the jobs. To retrieve the twenty next most recent jobs, use the nextToken string returned with the array.

    Args:
        max_results(int, optional): Optional. Number of jobs, up to twenty, that will be returned at one time. Defaults to None.
        next_token(str, optional): Optional. Use this string, provided with the response to a previous request, to request the next batch of jobs. Defaults to None.
        order(str, optional): Optional. When you request lists of resources, you can specify whether they are sorted in ASCENDING or DESCENDING order. Default varies by resource. Defaults to None.
        queue(str, optional): Optional. Provide a queue name to get back only jobs from that queue. Defaults to None.
        status(str, optional): Optional. A job's status can be SUBMITTED, PROGRESSING, COMPLETE, CANCELED, or ERROR. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.jobs.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.jobs.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="list_jobs",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "Order": order,
            "Queue": queue,
            "Status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def change(
    hub, ctx, queue_url: str, receipt_handle: str, visibility_timeout: int
) -> None:
    r"""
    **Autogenerated function**

    Changes the visibility timeout of a specified message in a queue to a new value. The default visibility timeout for a message is 30 seconds. The minimum is 0 seconds. The maximum is 12 hours. For more information, see Visibility Timeout in the Amazon SQS Developer Guide. For example, you have a message with a visibility timeout of 5 minutes. After 3 minutes, you call ChangeMessageVisibility with a timeout of 10 minutes. You can continue to call ChangeMessageVisibility to extend the visibility timeout to the maximum allowed time. If you try to extend the visibility timeout beyond the maximum, your request is rejected. An Amazon SQS message has three basic states:   Sent to a queue by a producer.   Received from the queue by a consumer.   Deleted from the queue.   A message is considered to be stored after it is sent to a queue by a producer, but not yet received from the queue by a consumer (that is, between states 1 and 2). There is no limit to the number of stored messages. A message is considered to be in flight after it is received from a queue by a consumer, but not yet deleted from the queue (that is, between states 2 and 3). There is a limit to the number of inflight messages. Limits that apply to inflight messages are unrelated to the unlimited number of stored messages. For most standard queues (depending on queue traffic and message backlog), there can be a maximum of approximately 120,000 inflight messages (received from a queue by a consumer, but not yet deleted from the queue). If you reach this limit, Amazon SQS returns the OverLimit error message. To avoid reaching the limit, you should delete messages from the queue after they're processed. You can also increase the number of queues you use to process your messages. To request a limit increase, file a support request. For FIFO queues, there can be a maximum of 20,000 inflight messages (received from a queue by a consumer, but not yet deleted from the queue). If you reach this limit, Amazon SQS returns no error messages.  If you attempt to set the VisibilityTimeout to a value greater than the maximum time left, Amazon SQS returns an error. Amazon SQS doesn't automatically recalculate and increase the timeout to the maximum remaining time. Unlike with a queue, when you change the visibility timeout for a specific message the timeout value is applied immediately but isn't saved in memory for that message. If you don't delete a message after it is received, the visibility timeout for the message reverts to the original timeout value (not to the value you set using the ChangeMessageVisibility action) the next time the message is received.

    Args:
        queue_url(str): The URL of the Amazon SQS queue whose message's visibility is changed. Queue URLs and names are case-sensitive.
        receipt_handle(str): The receipt handle associated with the message whose visibility timeout is changed. This parameter is returned by the  ReceiveMessage  action.
        visibility_timeout(int): The new value for the message's visibility timeout (in seconds). Values range: 0 to 43200. Maximum: 12 hours.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.message.visibility.init.change(
                ctx, queue_url=value, receipt_handle=value, visibility_timeout=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.message.visibility.init.change queue_url=value, receipt_handle=value, visibility_timeout=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="change_message_visibility",
        op_kwargs={
            "QueueUrl": queue_url,
            "ReceiptHandle": receipt_handle,
            "VisibilityTimeout": visibility_timeout,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    parameter_group_name: str,
    parameter_group_family: str,
    description: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon Redshift parameter group. Creating parameter groups is independent of creating clusters. You can associate a cluster with a parameter group when you create the cluster. You can also associate an existing cluster with a parameter group after the cluster is created by using ModifyCluster.  Parameters in the parameter group define specific behavior that applies to the databases you create on the cluster. For more information about parameters and parameter groups, go to Amazon Redshift Parameter Groups in the Amazon Redshift Cluster Management Guide.

    Args:
        parameter_group_name(str): The name of the cluster parameter group. Constraints:   Must be 1 to 255 alphanumeric characters or hyphens   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.   Must be unique withing your Amazon Web Services account.    This value is stored as a lower-case string. .
        parameter_group_family(str): The Amazon Redshift engine version to which the cluster parameter group applies. The cluster engine version determines the set of parameters. To get a list of valid parameter group family names, you can call DescribeClusterParameterGroups. By default, Amazon Redshift returns a list of all the parameter groups that are owned by your Amazon Web Services account, including the default parameter groups for each Amazon Redshift engine version. The parameter group family names associated with the default parameter groups provide you the valid values. For example, a valid family name is "redshift-1.0". .
        description(str): A description of the parameter group.
        tags(List, optional): A list of tag instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.parameter.group.create(
                ctx, parameter_group_name=value, parameter_group_family=value, description=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.parameter.group.create parameter_group_name=value, parameter_group_family=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="create_cluster_parameter_group",
        op_kwargs={
            "ParameterGroupName": parameter_group_name,
            "ParameterGroupFamily": parameter_group_family,
            "Description": description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, parameter_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a specified Amazon Redshift parameter group.  You cannot delete a parameter group if it is associated with a cluster.

    Args:
        parameter_group_name(str): The name of the parameter group to be deleted. Constraints:   Must be the name of an existing cluster parameter group.   Cannot delete a default cluster parameter group.  .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.parameter.group.delete(
                ctx, parameter_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.parameter.group.delete parameter_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="delete_cluster_parameter_group",
        op_kwargs={"ParameterGroupName": parameter_group_name},
    )


async def describe_all(
    hub,
    ctx,
    parameter_group_name: str = None,
    max_records: int = None,
    marker: str = None,
    tag_keys: List = None,
    tag_values: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of Amazon Redshift parameter groups, including parameter groups you created and the default parameter group. For each parameter group, the response includes the parameter group name, description, and parameter group family name. You can optionally specify a name to retrieve the description of a specific parameter group.  For more information about parameters and parameter groups, go to Amazon Redshift Parameter Groups in the Amazon Redshift Cluster Management Guide. If you specify both tag keys and tag values in the same request, Amazon Redshift returns all parameter groups that match any combination of the specified keys and values. For example, if you have owner and environment for tag keys, and admin and test for tag values, all parameter groups that have any combination of those values are returned. If both tag keys and values are omitted from the request, parameter groups are returned regardless of whether they have tag keys or values associated with them.

    Args:
        parameter_group_name(str, optional): The name of a specific parameter group for which to return details. By default, details about all parameter groups and the default parameter group are returned. Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 100  Constraints: minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeClusterParameterGroups request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.
        tag_keys(List, optional): A tag key or keys for which you want to return all matching cluster parameter groups that are associated with the specified key or keys. For example, suppose that you have parameter groups that are tagged with keys called owner and environment. If you specify both of these tag keys in the request, Amazon Redshift returns a response with the parameter groups that have either or both of these tag keys associated with them. Defaults to None.
        tag_values(List, optional): A tag value or values for which you want to return all matching cluster parameter groups that are associated with the specified tag value or values. For example, suppose that you have parameter groups that are tagged with values called admin and test. If you specify both of these tag values in the request, Amazon Redshift returns a response with the parameter groups that have either or both of these tag values associated with them. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.parameter.group.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.parameter.group.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_cluster_parameter_groups",
        op_kwargs={
            "ParameterGroupName": parameter_group_name,
            "MaxRecords": max_records,
            "Marker": marker,
            "TagKeys": tag_keys,
            "TagValues": tag_values,
        },
    )


async def modify(hub, ctx, parameter_group_name: str, parameters: List) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the parameters of a parameter group. For the parameters parameter, it can't contain ASCII characters.  For more information about parameters and parameter groups, go to Amazon Redshift Parameter Groups in the Amazon Redshift Cluster Management Guide.

    Args:
        parameter_group_name(str): The name of the parameter group to be modified.
        parameters(List): An array of parameters to be modified. A maximum of 20 parameters can be modified in a single request. For each parameter to be modified, you must supply at least the parameter name and parameter value; other name-value pairs of the parameter are optional. For the workload management (WLM) configuration, you must supply all the name-value pairs in the wlm_json_configuration parameter.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.parameter.group.modify(
                ctx, parameter_group_name=value, parameters=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.parameter.group.modify parameter_group_name=value, parameters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="modify_cluster_parameter_group",
        op_kwargs={
            "ParameterGroupName": parameter_group_name,
            "Parameters": parameters,
        },
    )


async def reset(
    hub,
    ctx,
    parameter_group_name: str,
    reset_all_parameters: bool = None,
    parameters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sets one or more parameters of the specified parameter group to their default values and sets the source values of the parameters to "engine-default". To reset the entire parameter group specify the ResetAllParameters parameter. For parameter changes to take effect you must reboot any associated clusters.

    Args:
        parameter_group_name(str): The name of the cluster parameter group to be reset.
        reset_all_parameters(bool, optional): If true, all parameters in the specified parameter group will be reset to their default values.  Default: true . Defaults to None.
        parameters(List, optional): An array of names of parameters to be reset. If ResetAllParameters option is not used, then at least one parameter name must be supplied.  Constraints: A maximum of 20 parameters can be reset in a single request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.parameter.group.reset(
                ctx, parameter_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.parameter.group.reset parameter_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="reset_cluster_parameter_group",
        op_kwargs={
            "ParameterGroupName": parameter_group_name,
            "ResetAllParameters": reset_all_parameters,
            "Parameters": parameters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    display_name: str,
    provider_name: str,
    idempotency_token: str,
    accept_language: str = None,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a portfolio. A delegated admin is authorized to invoke this command.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        display_name(str): The name to use for display purposes.
        description(str, optional): The description of the portfolio. Defaults to None.
        provider_name(str): The name of the portfolio provider.
        tags(List, optional): One or more tags. Defaults to None.
        idempotency_token(str): A unique identifier that you provide to ensure idempotency. If multiple requests differ only by the idempotency token, the same response is returned for each repeated request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.portfolio.init.create(
                ctx, display_name=value, provider_name=value, idempotency_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.portfolio.init.create display_name=value, provider_name=value, idempotency_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="create_portfolio",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "DisplayName": display_name,
            "Description": description,
            "ProviderName": provider_name,
            "Tags": tags,
            "IdempotencyToken": idempotency_token,
        },
    )


async def delete(hub, ctx, id_: str, accept_language: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified portfolio. You cannot delete a portfolio if it was shared with you or if it has associated products, users, constraints, or shared accounts. A delegated admin is authorized to invoke this command.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        id_(str): The portfolio identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.portfolio.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.portfolio.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="delete_portfolio",
        op_kwargs={"AcceptLanguage": accept_language, "Id": id_},
    )


async def describe(hub, ctx, id_: str, accept_language: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the specified portfolio. A delegated admin is authorized to invoke this command.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        id_(str): The portfolio identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.portfolio.init.describe(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.portfolio.init.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="describe_portfolio",
        op_kwargs={"AcceptLanguage": accept_language, "Id": id_},
    )


async def list_all(
    hub, ctx, accept_language: str = None, page_token: str = None, page_size: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all portfolios in the catalog.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        page_token(str, optional): The page token for the next set of results. To retrieve the first set of results, use null. Defaults to None.
        page_size(int, optional): The maximum number of items to return with this call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.portfolio.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.portfolio.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="list_portfolios",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "PageToken": page_token,
            "PageSize": page_size,
        },
    )


async def update(
    hub,
    ctx,
    id_: str,
    accept_language: str = None,
    display_name: str = None,
    description: str = None,
    provider_name: str = None,
    add_tags: List = None,
    remove_tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified portfolio. You cannot update a product that was shared with you.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        id_(str): The portfolio identifier.
        display_name(str, optional): The name to use for display purposes. Defaults to None.
        description(str, optional): The updated description of the portfolio. Defaults to None.
        provider_name(str, optional): The updated name of the portfolio provider. Defaults to None.
        add_tags(List, optional): The tags to add. Defaults to None.
        remove_tags(List, optional): The tags to remove. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.portfolio.init.update(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.portfolio.init.update id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="update_portfolio",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "Id": id_,
            "DisplayName": display_name,
            "Description": description,
            "ProviderName": provider_name,
            "AddTags": add_tags,
            "RemoveTags": remove_tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the configuration settings for storing data classification results.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.classification.export_configuration.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.classification.export_configuration.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="get_classification_export_configuration",
        op_kwargs={},
    )


async def put(hub, ctx, configuration: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates the configuration settings for storing data classification results.

    Args:
        configuration(Dict): The location to store data classification results in, and the encryption settings to use when storing results in that location.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.classification.export_configuration.put(
                ctx, configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.classification.export_configuration.put configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="put_classification_export_configuration",
        op_kwargs={"configuration": configuration},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "active_receipt_rule_set"


__func_alias__ = {"set_": "set"}


async def describe(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Returns the metadata and receipt rules for the receipt rule set that is currently active. For information about setting up receipt rule sets, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.active_receipt_rule_set_.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.active_receipt_rule_set.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="describe_active_receipt_rule_set",
        op_kwargs={},
    )


async def set_(hub, ctx, rule_set_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Sets the specified receipt rule set as the active receipt rule set.  To disable your email-receiving through Amazon SES completely, you can call this API with RuleSetName set to null.  For information about managing receipt rule sets, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        rule_set_name(str, optional): The name of the receipt rule set to make active. Setting this value to null disables all email receiving. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.active_receipt_rule_set_.set(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.active_receipt_rule_set.set
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="set_active_receipt_rule_set",
        op_kwargs={"RuleSetName": rule_set_name},
    )
